# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 16.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'To_PerlLB'}{'format'} = 's'; # string
$Unicode::UCD::SwashInfo{'To_PerlLB'}{'missing'} = 'Alphabetic';

return <<'END';
0	8	Combining_Mark
9		Break_After
A		Line_Feed
B	C	Mandatory_Break
D		Carriage_Return
E	1F	Combining_Mark
20		Space
21		Exclamation
22		Quotation
24		Prefix_Numeric
25		Postfix_Numeric
27		Quotation
28		Open_Punctuation
29		Close_Parenthesis
2B		Prefix_Numeric
2C		Infix_Numeric
2D		Hyphen
2E		Infix_Numeric
2F		Break_Symbols
30	39	Numeric
3A	3B	Infix_Numeric
3F		Exclamation
5B		Open_Punctuation
5C		Prefix_Numeric
5D		Close_Parenthesis
7B		Open_Punctuation
7C		Break_After
7D		Close_Punctuation
7F	84	Combining_Mark
85		Next_Line
86	9F	Combining_Mark
A0		Glue
A1		Open_Punctuation
A2		Postfix_Numeric
A3	A5	Prefix_Numeric
A9		ExtPict_AL
AB		Pi_QU
AD		Break_After
AE		ExtPict_AL
B0		Postfix_Numeric
B1		Prefix_Numeric
B4		Break_Before
BB		Pf_QU
BF		Open_Punctuation
2C8		Break_Before
2CC		Break_Before
2DF		Break_Before
300	34E	Combining_Mark
34F		Glue
350	35B	Combining_Mark
35C	362	Glue
363	36F	Combining_Mark
37E		Infix_Numeric
483	489	Combining_Mark
589		Infix_Numeric
58A		Break_After
58F		Prefix_Numeric
591	5BD	Combining_Mark
5BE		Break_After
5BF		Combining_Mark
5C1	5C2	Combining_Mark
5C4	5C5	Combining_Mark
5C6		Exclamation
5C7		Combining_Mark
5D0	5EA	Hebrew_Letter
5EF	5F2	Hebrew_Letter
600	605	Numeric
609	60B	Postfix_Numeric
60C	60D	Infix_Numeric
610	61A	Combining_Mark
61B		Exclamation
61C		Combining_Mark
61D	61F	Exclamation
64B	65F	Combining_Mark
660	669	Numeric
66A		Postfix_Numeric
66B	66C	Numeric
670		Combining_Mark
6D4		Exclamation
6D6	6DC	Combining_Mark
6DD		Numeric
6DF	6E4	Combining_Mark
6E7	6E8	Combining_Mark
6EA	6ED	Combining_Mark
6F0	6F9	Numeric
711		Combining_Mark
730	74A	Combining_Mark
7A6	7B0	Combining_Mark
7C0	7C9	Numeric
7EB	7F3	Combining_Mark
7F8		Infix_Numeric
7F9		Exclamation
7FD		Combining_Mark
7FE	7FF	Prefix_Numeric
816	819	Combining_Mark
81B	823	Combining_Mark
825	827	Combining_Mark
829	82D	Combining_Mark
859	85B	Combining_Mark
890	891	Numeric
897	89F	Combining_Mark
8CA	8E1	Combining_Mark
8E2		Numeric
8E3	903	Combining_Mark
93A	93C	Combining_Mark
93E	94F	Combining_Mark
951	957	Combining_Mark
962	963	Combining_Mark
964	965	Break_After
966	96F	Numeric
981	983	Combining_Mark
9BC		Combining_Mark
9BE	9C4	Combining_Mark
9C7	9C8	Combining_Mark
9CB	9CD	Combining_Mark
9D7		Combining_Mark
9E2	9E3	Combining_Mark
9E6	9EF	Numeric
9F2	9F3	Postfix_Numeric
9F9		Postfix_Numeric
9FB		Prefix_Numeric
9FE		Combining_Mark
A01	A03	Combining_Mark
A3C		Combining_Mark
A3E	A42	Combining_Mark
A47	A48	Combining_Mark
A4B	A4D	Combining_Mark
A51		Combining_Mark
A66	A6F	Numeric
A70	A71	Combining_Mark
A75		Combining_Mark
A81	A83	Combining_Mark
ABC		Combining_Mark
ABE	AC5	Combining_Mark
AC7	AC9	Combining_Mark
ACB	ACD	Combining_Mark
AE2	AE3	Combining_Mark
AE6	AEF	Numeric
AF1		Prefix_Numeric
AFA	AFF	Combining_Mark
B01	B03	Combining_Mark
B3C		Combining_Mark
B3E	B44	Combining_Mark
B47	B48	Combining_Mark
B4B	B4D	Combining_Mark
B55	B57	Combining_Mark
B62	B63	Combining_Mark
B66	B6F	Numeric
B82		Combining_Mark
BBE	BC2	Combining_Mark
BC6	BC8	Combining_Mark
BCA	BCD	Combining_Mark
BD7		Combining_Mark
BE6	BEF	Numeric
BF9		Prefix_Numeric
C00	C04	Combining_Mark
C3C		Combining_Mark
C3E	C44	Combining_Mark
C46	C48	Combining_Mark
C4A	C4D	Combining_Mark
C55	C56	Combining_Mark
C62	C63	Combining_Mark
C66	C6F	Numeric
C77		Break_Before
C81	C83	Combining_Mark
C84		Break_Before
CBC		Combining_Mark
CBE	CC4	Combining_Mark
CC6	CC8	Combining_Mark
CCA	CCD	Combining_Mark
CD5	CD6	Combining_Mark
CE2	CE3	Combining_Mark
CE6	CEF	Numeric
CF3		Combining_Mark
D00	D03	Combining_Mark
D3B	D3C	Combining_Mark
D3E	D44	Combining_Mark
D46	D48	Combining_Mark
D4A	D4D	Combining_Mark
D57		Combining_Mark
D62	D63	Combining_Mark
D66	D6F	Numeric
D79		Postfix_Numeric
D81	D83	Combining_Mark
DCA		Combining_Mark
DCF	DD4	Combining_Mark
DD6		Combining_Mark
DD8	DDF	Combining_Mark
DE6	DEF	Numeric
DF2	DF3	Combining_Mark
E31		Combining_Mark
E34	E3A	Combining_Mark
E3F		Prefix_Numeric
E47	E4E	Combining_Mark
E50	E59	Numeric
E5A	E5B	Break_After
EB1		Combining_Mark
EB4	EBC	Combining_Mark
EC8	ECE	Combining_Mark
ED0	ED9	Numeric
F01	F04	Break_Before
F06	F07	Break_Before
F08		Glue
F09	F0A	Break_Before
F0B		Break_After
F0C		Glue
F0D	F11	Exclamation
F12		Glue
F14		Exclamation
F18	F19	Combining_Mark
F20	F29	Numeric
F34		Break_After
F35		Combining_Mark
F37		Combining_Mark
F39		Combining_Mark
F3A		Open_Punctuation
F3B		Close_Punctuation
F3C		Open_Punctuation
F3D		Close_Punctuation
F3E	F3F	Combining_Mark
F71	F7E	Combining_Mark
F7F		Break_After
F80	F84	Combining_Mark
F85		Break_After
F86	F87	Combining_Mark
F8D	F97	Combining_Mark
F99	FBC	Combining_Mark
FBE	FBF	Break_After
FC6		Combining_Mark
FD0	FD1	Break_Before
FD2		Break_After
FD3		Break_Before
FD9	FDA	Glue
102B	103E	Combining_Mark
1040	1049	Numeric
104A	104B	Break_After
1056	1059	Combining_Mark
105E	1060	Combining_Mark
1062	1064	Combining_Mark
1067	106D	Combining_Mark
1071	1074	Combining_Mark
1082	108D	Combining_Mark
108F		Combining_Mark
1090	1099	Numeric
109A	109D	Combining_Mark
1100	115F	JL
1160	11A7	JV
11A8	11FF	JT
135D	135F	Combining_Mark
1361		Break_After
1400		Break_After
1680		Break_After
169B		Open_Punctuation
169C		Close_Punctuation
16EB	16ED	Break_After
1712	1715	Combining_Mark
1732	1734	Combining_Mark
1735	1736	Break_After
1752	1753	Combining_Mark
1772	1773	Combining_Mark
17B4	17D3	Combining_Mark
17D4	17D5	Break_After
17D6		Nonstarter
17D8		Break_After
17DA		Break_After
17DB		Prefix_Numeric
17DD		Combining_Mark
17E0	17E9	Numeric
1802	1803	Exclamation
1804	1805	Break_After
1806		Break_Before
1808	1809	Exclamation
180B	180D	Combining_Mark
180E		Glue
180F		Combining_Mark
1810	1819	Numeric
1885	1886	Combining_Mark
18A9		Combining_Mark
1920	192B	Combining_Mark
1930	193B	Combining_Mark
1944	1945	Exclamation
1946	194F	Numeric
19D0	19DA	Numeric
1A17	1A1B	Combining_Mark
1A55	1A5E	Combining_Mark
1A60	1A7C	Combining_Mark
1A7F		Combining_Mark
1A80	1A89	Numeric
1A90	1A99	Numeric
1AB0	1ACE	Combining_Mark
1B00	1B04	Combining_Mark
1B05	1B33	Aksara
1B34	1B43	Combining_Mark
1B44		Virama
1B45	1B4C	Aksara
1B4E	1B4F	Break_After
1B50	1B59	Aksara_Start
1B5A	1B5B	Break_After
1B5C		Ideographic
1B5D	1B60	Break_After
1B61	1B6A	Ideographic
1B6B	1B73	Combining_Mark
1B74	1B7C	Ideographic
1B7D	1B7F	Break_After
1B80	1B82	Combining_Mark
1BA1	1BAD	Combining_Mark
1BB0	1BB9	Numeric
1BC0	1BE5	Aksara_Start
1BE6	1BF1	Combining_Mark
1BF2	1BF3	Virama_Final
1C24	1C37	Combining_Mark
1C3B	1C3F	Break_After
1C40	1C49	Numeric
1C50	1C59	Numeric
1C7E	1C7F	Break_After
1CD0	1CD2	Combining_Mark
1CD4	1CE8	Combining_Mark
1CED		Combining_Mark
1CF4		Combining_Mark
1CF7	1CF9	Combining_Mark
1DC0	1DCC	Combining_Mark
1DCD		Glue
1DCE	1DFB	Combining_Mark
1DFC		Glue
1DFD	1DFF	Combining_Mark
1FFD		Break_Before
2000	2006	Break_After
2007		Glue
2008	200A	Break_After
200B		ZWSpace
200C		Combining_Mark
200D		ZWJ
200E	200F	Combining_Mark
2010		U2010_BA
2011		Glue
2012	2013	Break_After
2014		Break_Both
2018		Pi_QU
2019		Pf_QU
201A		Open_Punctuation
201B	201C	Pi_QU
201D		Pf_QU
201E		Open_Punctuation
201F		Pi_QU
2024	2026	Inseparable
2027		Break_After
2028	2029	Mandatory_Break
202A	202E	Combining_Mark
202F		Glue
2030	2037	Postfix_Numeric
2039		Pi_QU
203A		Pf_QU
203C		ExtPict_NS
203D		Nonstarter
2044		Infix_Numeric
2045		Open_Punctuation
2046		Close_Punctuation
2047	2048	Nonstarter
2049		ExtPict_NS
2056		Break_After
2057		Postfix_Numeric
2058	205B	Break_After
205D	205F	Break_After
2060		Word_Joiner
2066	206F	Combining_Mark
207D		Open_Punctuation
207E		Close_Punctuation
208D		Open_Punctuation
208E		Close_Punctuation
20A0	20A6	Prefix_Numeric
20A7		Postfix_Numeric
20A8		Prefix_Numeric
20A9		EA_PR
20AA	20B5	Prefix_Numeric
20B6		Postfix_Numeric
20B7	20BA	Prefix_Numeric
20BB		Postfix_Numeric
20BC	20BD	Prefix_Numeric
20BE		Postfix_Numeric
20BF		Prefix_Numeric
20C0		Postfix_Numeric
20C1	20CF	Prefix_Numeric
20D0	20F0	Combining_Mark
2103		Postfix_Numeric
2109		Postfix_Numeric
2116		Prefix_Numeric
2122		ExtPict_AL
2139		ExtPict_AL
2194	2199	ExtPict_AL
21A9	21AA	ExtPict_AL
2212	2213	Prefix_Numeric
22EF		Inseparable
2308		Open_Punctuation
2309		Close_Punctuation
230A		Open_Punctuation
230B		Close_Punctuation
231A	231B	EA_ExtPict_ID
2328		ExtPict_AL
2329		EA_OP
232A		EA_CL
2388		ExtPict_AL
23CF		ExtPict_AL
23E9	23EC	EA_ExtPict_AL
23ED	23EF	ExtPict_AL
23F0		EA_ExtPict_ID
23F1	23F2	ExtPict_ID
23F3		EA_ExtPict_ID
23F8	23FA	ExtPict_AL
24C2		ExtPict_AL
25AA	25AB	ExtPict_AL
25B6		ExtPict_AL
25C0		ExtPict_AL
25CC		Dotted_Circle_AL
25FB	25FC	ExtPict_AL
25FD	25FE	EA_ExtPict_AL
2600	2603	ExtPict_ID
2604	2605	ExtPict_AL
2607	2612	ExtPict_AL
2614	2615	EA_ExtPict_ID
2616	2617	ExtPict_AL
2618		ExtPict_ID
2619		ExtPict_AL
261A	261C	ExtPict_ID
261D		E_Base
261E	261F	ExtPict_ID
2620	262F	ExtPict_AL
2630	2637	EA_ExtPict_AL
2638		ExtPict_AL
2639	263B	ExtPict_ID
263C	2647	ExtPict_AL
2648	2653	EA_ExtPict_AL
2654	2667	ExtPict_AL
2668		ExtPict_ID
2669	267E	ExtPict_AL
267F		EA_ExtPict_ID
2680	2685	ExtPict_AL
268A	268F	EA_AL
2690	2692	ExtPict_AL
2693		EA_ExtPict_AL
2694	26A0	ExtPict_AL
26A1		EA_ExtPict_AL
26A2	26A9	ExtPict_AL
26AA	26AB	EA_ExtPict_AL
26AC	26BC	ExtPict_AL
26BD	26BE	EA_ExtPict_ID
26BF	26C3	ExtPict_ID
26C4	26C5	EA_ExtPict_ID
26C6	26C8	ExtPict_ID
26C9	26CC	ExtPict_AL
26CD		ExtPict_ID
26CE		EA_ExtPict_AL
26CF	26D1	ExtPict_ID
26D2		ExtPict_AL
26D3		ExtPict_ID
26D4		EA_ExtPict_ID
26D5	26D7	ExtPict_AL
26D8	26D9	ExtPict_ID
26DA	26DB	ExtPict_AL
26DC		ExtPict_ID
26DD	26DE	ExtPict_AL
26DF	26E1	ExtPict_ID
26E2	26E9	ExtPict_AL
26EA		EA_ExtPict_ID
26EB	26F0	ExtPict_AL
26F1		ExtPict_ID
26F2	26F3	EA_ExtPict_ID
26F4		ExtPict_ID
26F5		EA_ExtPict_ID
26F6		ExtPict_AL
26F7	26F8	ExtPict_ID
26F9		E_Base
26FA		EA_ExtPict_ID
26FB	26FC	ExtPict_AL
26FD		EA_ExtPict_ID
26FE	2704	ExtPict_ID
2705		EA_ExtPict_AL
2708	2709	ExtPict_ID
270A	270B	EA_EB
270C	270D	E_Base
270E	2712	ExtPict_AL
2714		ExtPict_AL
2716		ExtPict_AL
271D		ExtPict_AL
2721		ExtPict_AL
2728		EA_ExtPict_AL
2733	2734	ExtPict_AL
2744		ExtPict_AL
2747		ExtPict_AL
274C		EA_ExtPict_AL
274E		EA_ExtPict_AL
2753	2755	EA_ExtPict_AL
2757		EA_ExtPict_AL
275B	2760	Quotation
2762		Exclamation
2763		ExtPict_EX
2764		ExtPict_ID
2765	2767	ExtPict_AL
2768		Open_Punctuation
2769		Close_Punctuation
276A		Open_Punctuation
276B		Close_Punctuation
276C		Open_Punctuation
276D		Close_Punctuation
276E		Open_Punctuation
276F		Close_Punctuation
2770		Open_Punctuation
2771		Close_Punctuation
2772		Open_Punctuation
2773		Close_Punctuation
2774		Open_Punctuation
2775		Close_Punctuation
2795	2797	EA_ExtPict_AL
27A1		ExtPict_AL
27B0		EA_ExtPict_AL
27BF		EA_ExtPict_AL
27C5		Open_Punctuation
27C6		Close_Punctuation
27E6		Open_Punctuation
27E7		Close_Punctuation
27E8		Open_Punctuation
27E9		Close_Punctuation
27EA		Open_Punctuation
27EB		Close_Punctuation
27EC		Open_Punctuation
27ED		Close_Punctuation
27EE		Open_Punctuation
27EF		Close_Punctuation
2934	2935	ExtPict_AL
2983		Open_Punctuation
2984		Close_Punctuation
2985		Open_Punctuation
2986		Close_Punctuation
2987		Open_Punctuation
2988		Close_Punctuation
2989		Open_Punctuation
298A		Close_Punctuation
298B		Open_Punctuation
298C		Close_Punctuation
298D		Open_Punctuation
298E		Close_Punctuation
298F		Open_Punctuation
2990		Close_Punctuation
2991		Open_Punctuation
2992		Close_Punctuation
2993		Open_Punctuation
2994		Close_Punctuation
2995		Open_Punctuation
2996		Close_Punctuation
2997		Open_Punctuation
2998		Close_Punctuation
29D8		Open_Punctuation
29D9		Close_Punctuation
29DA		Open_Punctuation
29DB		Close_Punctuation
29FC		Open_Punctuation
29FD		Close_Punctuation
2B05	2B07	ExtPict_AL
2B1B	2B1C	EA_ExtPict_AL
2B50		EA_ExtPict_AL
2B55		EA_ExtPict_AL
2CEF	2CF1	Combining_Mark
2CF9		Exclamation
2CFA	2CFC	Break_After
2CFE		Exclamation
2CFF		Break_After
2D70		Break_After
2D7F		Combining_Mark
2DE0	2DFF	Combining_Mark
2E00	2E01	Quotation
2E02		Pi_QU
2E03		Pf_QU
2E04		Pi_QU
2E05		Pf_QU
2E06	2E08	Quotation
2E09		Pi_QU
2E0A		Pf_QU
2E0B		Quotation
2E0C		Pi_QU
2E0D		Pf_QU
2E0E	2E15	Break_After
2E17		Break_After
2E18		Open_Punctuation
2E19		Break_After
2E1C		Pi_QU
2E1D		Pf_QU
2E20		Pi_QU
2E21		Pf_QU
2E22		Open_Punctuation
2E23		Close_Punctuation
2E24		Open_Punctuation
2E25		Close_Punctuation
2E26		Open_Punctuation
2E27		Close_Punctuation
2E28		Open_Punctuation
2E29		Close_Punctuation
2E2A	2E2D	Break_After
2E2E		Exclamation
2E30	2E31	Break_After
2E33	2E34	Break_After
2E3A	2E3B	Break_Both
2E3C	2E3E	Break_After
2E40	2E41	Break_After
2E42		Open_Punctuation
2E43	2E4A	Break_After
2E4C		Break_After
2E4E	2E4F	Break_After
2E53	2E54	Exclamation
2E55		Open_Punctuation
2E56		Close_Parenthesis
2E57		Open_Punctuation
2E58		Close_Parenthesis
2E59		Open_Punctuation
2E5A		Close_Parenthesis
2E5B		Open_Punctuation
2E5C		Close_Parenthesis
2E5D		Break_After
2E80	2E99	EA_ID
2E9B	2EF3	EA_ID
2F00	2FD5	EA_ID
2FF0	2FFF	EA_ID
3000		EA_BA
3001	3002	EA_CL
3003	3004	EA_ID
3005		EA_NS
3006	3007	EA_ID
3008		EA_OP
3009		EA_CL
300A		EA_OP
300B		EA_CL
300C		EA_OP
300D		EA_CL
300E		EA_OP
300F		EA_CL
3010		EA_OP
3011		EA_CL
3012	3013	EA_ID
3014		EA_OP
3015		EA_CL
3016		EA_OP
3017		EA_CL
3018		EA_OP
3019		EA_CL
301A		EA_OP
301B		EA_CL
301C		EA_NS
301D		EA_OP
301E	301F	EA_CL
3020	3029	EA_ID
302A	302F	EA_CM
3030		EA_ExtPict_ID
3031	3034	EA_ID
3035		EA_CM
3036	303A	EA_ID
303B	303C	EA_NS
303D		EA_ExtPict_ID
303E		EA_ID
303F		Ideographic
3041		EA_NS
3042		EA_ID
3043		EA_NS
3044		EA_ID
3045		EA_NS
3046		EA_ID
3047		EA_NS
3048		EA_ID
3049		EA_NS
304A	3062	EA_ID
3063		EA_NS
3064	3082	EA_ID
3083		EA_NS
3084		EA_ID
3085		EA_NS
3086		EA_ID
3087		EA_NS
3088	308D	EA_ID
308E		EA_NS
308F	3094	EA_ID
3095	3096	EA_NS
3099	309A	EA_CM
309B	309E	EA_NS
309F		EA_ID
30A0	30A1	EA_NS
30A2		EA_ID
30A3		EA_NS
30A4		EA_ID
30A5		EA_NS
30A6		EA_ID
30A7		EA_NS
30A8		EA_ID
30A9		EA_NS
30AA	30C2	EA_ID
30C3		EA_NS
30C4	30E2	EA_ID
30E3		EA_NS
30E4		EA_ID
30E5		EA_NS
30E6		EA_ID
30E7		EA_NS
30E8	30ED	EA_ID
30EE		EA_NS
30EF	30F4	EA_ID
30F5	30F6	EA_NS
30F7	30FA	EA_ID
30FB	30FE	EA_NS
30FF		EA_ID
3105	312F	EA_ID
3131	318E	EA_ID
3190	31E5	EA_ID
31EF		EA_ID
31F0	31FF	EA_NS
3200	321E	EA_ID
3220	3247	EA_ID
3250	3296	EA_ID
3297		EA_ExtPict_ID
3298		EA_ID
3299		EA_ExtPict_ID
329A	4DBF	EA_ID
4DC0	4DFF	EA_AL
4E00	A014	EA_ID
A015		EA_NS
A016	A48C	EA_ID
A490	A4C6	EA_ID
A4FE	A4FF	Break_After
A60D		Break_After
A60E		Exclamation
A60F		Break_After
A620	A629	Numeric
A66F	A672	Combining_Mark
A674	A67D	Combining_Mark
A69E	A69F	Combining_Mark
A6F0	A6F1	Combining_Mark
A6F3	A6F7	Break_After
A802		Combining_Mark
A806		Combining_Mark
A80B		Combining_Mark
A823	A827	Combining_Mark
A82C		Combining_Mark
A838		Postfix_Numeric
A874	A875	Break_Before
A876	A877	Exclamation
A880	A881	Combining_Mark
A8B4	A8C5	Combining_Mark
A8CE	A8CF	Break_After
A8D0	A8D9	Numeric
A8E0	A8F1	Combining_Mark
A8FC		Break_Before
A8FF		Combining_Mark
A900	A909	Numeric
A926	A92D	Combining_Mark
A92E	A92F	Break_After
A947	A953	Combining_Mark
A960	A97C	JL
A980	A983	Combining_Mark
A984	A9B2	Aksara
A9B3	A9BF	Combining_Mark
A9C0		Virama
A9C1	A9C6	Ideographic
A9C7	A9C9	Break_After
A9CA	A9CD	Ideographic
A9CF		Break_After
A9D0	A9D9	Aksara_Start
A9DE	A9DF	Ideographic
A9E5		Combining_Mark
A9F0	A9F9	Numeric
AA00	AA28	Aksara_Start
AA29	AA36	Combining_Mark
AA40	AA42	Break_After
AA43		Combining_Mark
AA44	AA4B	Break_After
AA4C	AA4D	Combining_Mark
AA50	AA59	Aksara_Start
AA5C		Ideographic
AA5D	AA5F	Break_After
AA7B	AA7D	Combining_Mark
AAB0		Combining_Mark
AAB2	AAB4	Combining_Mark
AAB7	AAB8	Combining_Mark
AABE	AABF	Combining_Mark
AAC1		Combining_Mark
AAEB	AAEF	Combining_Mark
AAF0	AAF1	Break_After
AAF5	AAF6	Combining_Mark
ABE3	ABEA	Combining_Mark
ABEB		Break_After
ABEC	ABED	Combining_Mark
ABF0	ABF9	Numeric
AC00		H2
AC01	AC1B	H3
AC1C		H2
AC1D	AC37	H3
AC38		H2
AC39	AC53	H3
AC54		H2
AC55	AC6F	H3
AC70		H2
AC71	AC8B	H3
AC8C		H2
AC8D	ACA7	H3
ACA8		H2
ACA9	ACC3	H3
ACC4		H2
ACC5	ACDF	H3
ACE0		H2
ACE1	ACFB	H3
ACFC		H2
ACFD	AD17	H3
AD18		H2
AD19	AD33	H3
AD34		H2
AD35	AD4F	H3
AD50		H2
AD51	AD6B	H3
AD6C		H2
AD6D	AD87	H3
AD88		H2
AD89	ADA3	H3
ADA4		H2
ADA5	ADBF	H3
ADC0		H2
ADC1	ADDB	H3
ADDC		H2
ADDD	ADF7	H3
ADF8		H2
ADF9	AE13	H3
AE14		H2
AE15	AE2F	H3
AE30		H2
AE31	AE4B	H3
AE4C		H2
AE4D	AE67	H3
AE68		H2
AE69	AE83	H3
AE84		H2
AE85	AE9F	H3
AEA0		H2
AEA1	AEBB	H3
AEBC		H2
AEBD	AED7	H3
AED8		H2
AED9	AEF3	H3
AEF4		H2
AEF5	AF0F	H3
AF10		H2
AF11	AF2B	H3
AF2C		H2
AF2D	AF47	H3
AF48		H2
AF49	AF63	H3
AF64		H2
AF65	AF7F	H3
AF80		H2
AF81	AF9B	H3
AF9C		H2
AF9D	AFB7	H3
AFB8		H2
AFB9	AFD3	H3
AFD4		H2
AFD5	AFEF	H3
AFF0		H2
AFF1	B00B	H3
B00C		H2
B00D	B027	H3
B028		H2
B029	B043	H3
B044		H2
B045	B05F	H3
B060		H2
B061	B07B	H3
B07C		H2
B07D	B097	H3
B098		H2
B099	B0B3	H3
B0B4		H2
B0B5	B0CF	H3
B0D0		H2
B0D1	B0EB	H3
B0EC		H2
B0ED	B107	H3
B108		H2
B109	B123	H3
B124		H2
B125	B13F	H3
B140		H2
B141	B15B	H3
B15C		H2
B15D	B177	H3
B178		H2
B179	B193	H3
B194		H2
B195	B1AF	H3
B1B0		H2
B1B1	B1CB	H3
B1CC		H2
B1CD	B1E7	H3
B1E8		H2
B1E9	B203	H3
B204		H2
B205	B21F	H3
B220		H2
B221	B23B	H3
B23C		H2
B23D	B257	H3
B258		H2
B259	B273	H3
B274		H2
B275	B28F	H3
B290		H2
B291	B2AB	H3
B2AC		H2
B2AD	B2C7	H3
B2C8		H2
B2C9	B2E3	H3
B2E4		H2
B2E5	B2FF	H3
B300		H2
B301	B31B	H3
B31C		H2
B31D	B337	H3
B338		H2
B339	B353	H3
B354		H2
B355	B36F	H3
B370		H2
B371	B38B	H3
B38C		H2
B38D	B3A7	H3
B3A8		H2
B3A9	B3C3	H3
B3C4		H2
B3C5	B3DF	H3
B3E0		H2
B3E1	B3FB	H3
B3FC		H2
B3FD	B417	H3
B418		H2
B419	B433	H3
B434		H2
B435	B44F	H3
B450		H2
B451	B46B	H3
B46C		H2
B46D	B487	H3
B488		H2
B489	B4A3	H3
B4A4		H2
B4A5	B4BF	H3
B4C0		H2
B4C1	B4DB	H3
B4DC		H2
B4DD	B4F7	H3
B4F8		H2
B4F9	B513	H3
B514		H2
B515	B52F	H3
B530		H2
B531	B54B	H3
B54C		H2
B54D	B567	H3
B568		H2
B569	B583	H3
B584		H2
B585	B59F	H3
B5A0		H2
B5A1	B5BB	H3
B5BC		H2
B5BD	B5D7	H3
B5D8		H2
B5D9	B5F3	H3
B5F4		H2
B5F5	B60F	H3
B610		H2
B611	B62B	H3
B62C		H2
B62D	B647	H3
B648		H2
B649	B663	H3
B664		H2
B665	B67F	H3
B680		H2
B681	B69B	H3
B69C		H2
B69D	B6B7	H3
B6B8		H2
B6B9	B6D3	H3
B6D4		H2
B6D5	B6EF	H3
B6F0		H2
B6F1	B70B	H3
B70C		H2
B70D	B727	H3
B728		H2
B729	B743	H3
B744		H2
B745	B75F	H3
B760		H2
B761	B77B	H3
B77C		H2
B77D	B797	H3
B798		H2
B799	B7B3	H3
B7B4		H2
B7B5	B7CF	H3
B7D0		H2
B7D1	B7EB	H3
B7EC		H2
B7ED	B807	H3
B808		H2
B809	B823	H3
B824		H2
B825	B83F	H3
B840		H2
B841	B85B	H3
B85C		H2
B85D	B877	H3
B878		H2
B879	B893	H3
B894		H2
B895	B8AF	H3
B8B0		H2
B8B1	B8CB	H3
B8CC		H2
B8CD	B8E7	H3
B8E8		H2
B8E9	B903	H3
B904		H2
B905	B91F	H3
B920		H2
B921	B93B	H3
B93C		H2
B93D	B957	H3
B958		H2
B959	B973	H3
B974		H2
B975	B98F	H3
B990		H2
B991	B9AB	H3
B9AC		H2
B9AD	B9C7	H3
B9C8		H2
B9C9	B9E3	H3
B9E4		H2
B9E5	B9FF	H3
BA00		H2
BA01	BA1B	H3
BA1C		H2
BA1D	BA37	H3
BA38		H2
BA39	BA53	H3
BA54		H2
BA55	BA6F	H3
BA70		H2
BA71	BA8B	H3
BA8C		H2
BA8D	BAA7	H3
BAA8		H2
BAA9	BAC3	H3
BAC4		H2
BAC5	BADF	H3
BAE0		H2
BAE1	BAFB	H3
BAFC		H2
BAFD	BB17	H3
BB18		H2
BB19	BB33	H3
BB34		H2
BB35	BB4F	H3
BB50		H2
BB51	BB6B	H3
BB6C		H2
BB6D	BB87	H3
BB88		H2
BB89	BBA3	H3
BBA4		H2
BBA5	BBBF	H3
BBC0		H2
BBC1	BBDB	H3
BBDC		H2
BBDD	BBF7	H3
BBF8		H2
BBF9	BC13	H3
BC14		H2
BC15	BC2F	H3
BC30		H2
BC31	BC4B	H3
BC4C		H2
BC4D	BC67	H3
BC68		H2
BC69	BC83	H3
BC84		H2
BC85	BC9F	H3
BCA0		H2
BCA1	BCBB	H3
BCBC		H2
BCBD	BCD7	H3
BCD8		H2
BCD9	BCF3	H3
BCF4		H2
BCF5	BD0F	H3
BD10		H2
BD11	BD2B	H3
BD2C		H2
BD2D	BD47	H3
BD48		H2
BD49	BD63	H3
BD64		H2
BD65	BD7F	H3
BD80		H2
BD81	BD9B	H3
BD9C		H2
BD9D	BDB7	H3
BDB8		H2
BDB9	BDD3	H3
BDD4		H2
BDD5	BDEF	H3
BDF0		H2
BDF1	BE0B	H3
BE0C		H2
BE0D	BE27	H3
BE28		H2
BE29	BE43	H3
BE44		H2
BE45	BE5F	H3
BE60		H2
BE61	BE7B	H3
BE7C		H2
BE7D	BE97	H3
BE98		H2
BE99	BEB3	H3
BEB4		H2
BEB5	BECF	H3
BED0		H2
BED1	BEEB	H3
BEEC		H2
BEED	BF07	H3
BF08		H2
BF09	BF23	H3
BF24		H2
BF25	BF3F	H3
BF40		H2
BF41	BF5B	H3
BF5C		H2
BF5D	BF77	H3
BF78		H2
BF79	BF93	H3
BF94		H2
BF95	BFAF	H3
BFB0		H2
BFB1	BFCB	H3
BFCC		H2
BFCD	BFE7	H3
BFE8		H2
BFE9	C003	H3
C004		H2
C005	C01F	H3
C020		H2
C021	C03B	H3
C03C		H2
C03D	C057	H3
C058		H2
C059	C073	H3
C074		H2
C075	C08F	H3
C090		H2
C091	C0AB	H3
C0AC		H2
C0AD	C0C7	H3
C0C8		H2
C0C9	C0E3	H3
C0E4		H2
C0E5	C0FF	H3
C100		H2
C101	C11B	H3
C11C		H2
C11D	C137	H3
C138		H2
C139	C153	H3
C154		H2
C155	C16F	H3
C170		H2
C171	C18B	H3
C18C		H2
C18D	C1A7	H3
C1A8		H2
C1A9	C1C3	H3
C1C4		H2
C1C5	C1DF	H3
C1E0		H2
C1E1	C1FB	H3
C1FC		H2
C1FD	C217	H3
C218		H2
C219	C233	H3
C234		H2
C235	C24F	H3
C250		H2
C251	C26B	H3
C26C		H2
C26D	C287	H3
C288		H2
C289	C2A3	H3
C2A4		H2
C2A5	C2BF	H3
C2C0		H2
C2C1	C2DB	H3
C2DC		H2
C2DD	C2F7	H3
C2F8		H2
C2F9	C313	H3
C314		H2
C315	C32F	H3
C330		H2
C331	C34B	H3
C34C		H2
C34D	C367	H3
C368		H2
C369	C383	H3
C384		H2
C385	C39F	H3
C3A0		H2
C3A1	C3BB	H3
C3BC		H2
C3BD	C3D7	H3
C3D8		H2
C3D9	C3F3	H3
C3F4		H2
C3F5	C40F	H3
C410		H2
C411	C42B	H3
C42C		H2
C42D	C447	H3
C448		H2
C449	C463	H3
C464		H2
C465	C47F	H3
C480		H2
C481	C49B	H3
C49C		H2
C49D	C4B7	H3
C4B8		H2
C4B9	C4D3	H3
C4D4		H2
C4D5	C4EF	H3
C4F0		H2
C4F1	C50B	H3
C50C		H2
C50D	C527	H3
C528		H2
C529	C543	H3
C544		H2
C545	C55F	H3
C560		H2
C561	C57B	H3
C57C		H2
C57D	C597	H3
C598		H2
C599	C5B3	H3
C5B4		H2
C5B5	C5CF	H3
C5D0		H2
C5D1	C5EB	H3
C5EC		H2
C5ED	C607	H3
C608		H2
C609	C623	H3
C624		H2
C625	C63F	H3
C640		H2
C641	C65B	H3
C65C		H2
C65D	C677	H3
C678		H2
C679	C693	H3
C694		H2
C695	C6AF	H3
C6B0		H2
C6B1	C6CB	H3
C6CC		H2
C6CD	C6E7	H3
C6E8		H2
C6E9	C703	H3
C704		H2
C705	C71F	H3
C720		H2
C721	C73B	H3
C73C		H2
C73D	C757	H3
C758		H2
C759	C773	H3
C774		H2
C775	C78F	H3
C790		H2
C791	C7AB	H3
C7AC		H2
C7AD	C7C7	H3
C7C8		H2
C7C9	C7E3	H3
C7E4		H2
C7E5	C7FF	H3
C800		H2
C801	C81B	H3
C81C		H2
C81D	C837	H3
C838		H2
C839	C853	H3
C854		H2
C855	C86F	H3
C870		H2
C871	C88B	H3
C88C		H2
C88D	C8A7	H3
C8A8		H2
C8A9	C8C3	H3
C8C4		H2
C8C5	C8DF	H3
C8E0		H2
C8E1	C8FB	H3
C8FC		H2
C8FD	C917	H3
C918		H2
C919	C933	H3
C934		H2
C935	C94F	H3
C950		H2
C951	C96B	H3
C96C		H2
C96D	C987	H3
C988		H2
C989	C9A3	H3
C9A4		H2
C9A5	C9BF	H3
C9C0		H2
C9C1	C9DB	H3
C9DC		H2
C9DD	C9F7	H3
C9F8		H2
C9F9	CA13	H3
CA14		H2
CA15	CA2F	H3
CA30		H2
CA31	CA4B	H3
CA4C		H2
CA4D	CA67	H3
CA68		H2
CA69	CA83	H3
CA84		H2
CA85	CA9F	H3
CAA0		H2
CAA1	CABB	H3
CABC		H2
CABD	CAD7	H3
CAD8		H2
CAD9	CAF3	H3
CAF4		H2
CAF5	CB0F	H3
CB10		H2
CB11	CB2B	H3
CB2C		H2
CB2D	CB47	H3
CB48		H2
CB49	CB63	H3
CB64		H2
CB65	CB7F	H3
CB80		H2
CB81	CB9B	H3
CB9C		H2
CB9D	CBB7	H3
CBB8		H2
CBB9	CBD3	H3
CBD4		H2
CBD5	CBEF	H3
CBF0		H2
CBF1	CC0B	H3
CC0C		H2
CC0D	CC27	H3
CC28		H2
CC29	CC43	H3
CC44		H2
CC45	CC5F	H3
CC60		H2
CC61	CC7B	H3
CC7C		H2
CC7D	CC97	H3
CC98		H2
CC99	CCB3	H3
CCB4		H2
CCB5	CCCF	H3
CCD0		H2
CCD1	CCEB	H3
CCEC		H2
CCED	CD07	H3
CD08		H2
CD09	CD23	H3
CD24		H2
CD25	CD3F	H3
CD40		H2
CD41	CD5B	H3
CD5C		H2
CD5D	CD77	H3
CD78		H2
CD79	CD93	H3
CD94		H2
CD95	CDAF	H3
CDB0		H2
CDB1	CDCB	H3
CDCC		H2
CDCD	CDE7	H3
CDE8		H2
CDE9	CE03	H3
CE04		H2
CE05	CE1F	H3
CE20		H2
CE21	CE3B	H3
CE3C		H2
CE3D	CE57	H3
CE58		H2
CE59	CE73	H3
CE74		H2
CE75	CE8F	H3
CE90		H2
CE91	CEAB	H3
CEAC		H2
CEAD	CEC7	H3
CEC8		H2
CEC9	CEE3	H3
CEE4		H2
CEE5	CEFF	H3
CF00		H2
CF01	CF1B	H3
CF1C		H2
CF1D	CF37	H3
CF38		H2
CF39	CF53	H3
CF54		H2
CF55	CF6F	H3
CF70		H2
CF71	CF8B	H3
CF8C		H2
CF8D	CFA7	H3
CFA8		H2
CFA9	CFC3	H3
CFC4		H2
CFC5	CFDF	H3
CFE0		H2
CFE1	CFFB	H3
CFFC		H2
CFFD	D017	H3
D018		H2
D019	D033	H3
D034		H2
D035	D04F	H3
D050		H2
D051	D06B	H3
D06C		H2
D06D	D087	H3
D088		H2
D089	D0A3	H3
D0A4		H2
D0A5	D0BF	H3
D0C0		H2
D0C1	D0DB	H3
D0DC		H2
D0DD	D0F7	H3
D0F8		H2
D0F9	D113	H3
D114		H2
D115	D12F	H3
D130		H2
D131	D14B	H3
D14C		H2
D14D	D167	H3
D168		H2
D169	D183	H3
D184		H2
D185	D19F	H3
D1A0		H2
D1A1	D1BB	H3
D1BC		H2
D1BD	D1D7	H3
D1D8		H2
D1D9	D1F3	H3
D1F4		H2
D1F5	D20F	H3
D210		H2
D211	D22B	H3
D22C		H2
D22D	D247	H3
D248		H2
D249	D263	H3
D264		H2
D265	D27F	H3
D280		H2
D281	D29B	H3
D29C		H2
D29D	D2B7	H3
D2B8		H2
D2B9	D2D3	H3
D2D4		H2
D2D5	D2EF	H3
D2F0		H2
D2F1	D30B	H3
D30C		H2
D30D	D327	H3
D328		H2
D329	D343	H3
D344		H2
D345	D35F	H3
D360		H2
D361	D37B	H3
D37C		H2
D37D	D397	H3
D398		H2
D399	D3B3	H3
D3B4		H2
D3B5	D3CF	H3
D3D0		H2
D3D1	D3EB	H3
D3EC		H2
D3ED	D407	H3
D408		H2
D409	D423	H3
D424		H2
D425	D43F	H3
D440		H2
D441	D45B	H3
D45C		H2
D45D	D477	H3
D478		H2
D479	D493	H3
D494		H2
D495	D4AF	H3
D4B0		H2
D4B1	D4CB	H3
D4CC		H2
D4CD	D4E7	H3
D4E8		H2
D4E9	D503	H3
D504		H2
D505	D51F	H3
D520		H2
D521	D53B	H3
D53C		H2
D53D	D557	H3
D558		H2
D559	D573	H3
D574		H2
D575	D58F	H3
D590		H2
D591	D5AB	H3
D5AC		H2
D5AD	D5C7	H3
D5C8		H2
D5C9	D5E3	H3
D5E4		H2
D5E5	D5FF	H3
D600		H2
D601	D61B	H3
D61C		H2
D61D	D637	H3
D638		H2
D639	D653	H3
D654		H2
D655	D66F	H3
D670		H2
D671	D68B	H3
D68C		H2
D68D	D6A7	H3
D6A8		H2
D6A9	D6C3	H3
D6C4		H2
D6C5	D6DF	H3
D6E0		H2
D6E1	D6FB	H3
D6FC		H2
D6FD	D717	H3
D718		H2
D719	D733	H3
D734		H2
D735	D74F	H3
D750		H2
D751	D76B	H3
D76C		H2
D76D	D787	H3
D788		H2
D789	D7A3	H3
D7B0	D7C6	JV
D7CB	D7FB	JT
F900	FAFF	EA_ID
FB1D		Hebrew_Letter
FB1E		Combining_Mark
FB1F	FB28	Hebrew_Letter
FB2A	FB36	Hebrew_Letter
FB38	FB3C	Hebrew_Letter
FB3E		Hebrew_Letter
FB40	FB41	Hebrew_Letter
FB43	FB44	Hebrew_Letter
FB46	FB4F	Hebrew_Letter
FD3E		Close_Punctuation
FD3F		Open_Punctuation
FDFC		Postfix_Numeric
FE00	FE0F	Combining_Mark
FE10	FE12	EA_CL
FE13	FE14	EA_NS
FE15	FE16	EA_EX
FE17		EA_OP
FE18		EA_CL
FE19		EA_IN
FE20		Glue
FE21		Combining_Mark
FE22		Glue
FE23		Combining_Mark
FE24		Glue
FE25		Combining_Mark
FE26	FE27	Glue
FE28		Combining_Mark
FE29		Glue
FE2A		Combining_Mark
FE2B		Glue
FE2C		Combining_Mark
FE2D	FE2E	Glue
FE2F		Combining_Mark
FE30	FE34	EA_ID
FE35		EA_OP
FE36		EA_CL
FE37		EA_OP
FE38		EA_CL
FE39		EA_OP
FE3A		EA_CL
FE3B		EA_OP
FE3C		EA_CL
FE3D		EA_OP
FE3E		EA_CL
FE3F		EA_OP
FE40		EA_CL
FE41		EA_OP
FE42		EA_CL
FE43		EA_OP
FE44		EA_CL
FE45	FE46	EA_ID
FE47		EA_OP
FE48		EA_CL
FE49	FE4F	EA_ID
FE50		EA_CL
FE51		EA_ID
FE52		EA_CL
FE54	FE55	EA_NS
FE56	FE57	EA_EX
FE58		EA_ID
FE59		EA_OP
FE5A		EA_CL
FE5B		EA_OP
FE5C		EA_CL
FE5D		EA_OP
FE5E		EA_CL
FE5F	FE66	EA_ID
FE68		EA_ID
FE69		EA_PR
FE6A		EA_PO
FE6B		EA_ID
FEFF		Word_Joiner
FF01		EA_EX
FF02	FF03	EA_ID
FF04		EA_PR
FF05		EA_PO
FF06	FF07	EA_ID
FF08		EA_OP
FF09		EA_CL
FF0A	FF0B	EA_ID
FF0C		EA_CL
FF0D		EA_ID
FF0E		EA_CL
FF0F	FF19	EA_ID
FF1A	FF1B	EA_NS
FF1C	FF1E	EA_ID
FF1F		EA_EX
FF20	FF3A	EA_ID
FF3B		EA_OP
FF3C		EA_ID
FF3D		EA_CL
FF3E	FF5A	EA_ID
FF5B		EA_OP
FF5C		EA_ID
FF5D		EA_CL
FF5E		EA_ID
FF5F		EA_OP
FF60	FF61	EA_CL
FF62		EA_OP
FF63	FF64	EA_CL
FF65		EA_NS
FF66		EA_ID
FF67	FF70	EA_NS
FF71	FF9D	EA_ID
FF9E	FF9F	EA_NS
FFA0	FFBE	EA_ID
FFC2	FFC7	EA_ID
FFCA	FFCF	EA_ID
FFD2	FFD7	EA_ID
FFDA	FFDC	EA_ID
FFE0		EA_PO
FFE1		EA_PR
FFE2	FFE4	EA_ID
FFE5	FFE6	EA_PR
FFE8	FFEE	EA_AL
FFF9	FFFB	Combining_Mark
FFFC		Contingent_Break
10100	10102	Break_After
101FD		Combining_Mark
102E0		Combining_Mark
10376	1037A	Combining_Mark
1039F		Break_After
103D0		Break_After
104A0	104A9	Numeric
10857		Break_After
1091F		Break_After
10A01	10A03	Combining_Mark
10A05	10A06	Combining_Mark
10A0C	10A0F	Combining_Mark
10A38	10A3A	Combining_Mark
10A3F		Combining_Mark
10A50	10A57	Break_After
10AE5	10AE6	Combining_Mark
10AF0	10AF5	Break_After
10AF6		Inseparable
10B39	10B3F	Break_After
10D24	10D27	Combining_Mark
10D30	10D39	Numeric
10D40	10D49	Numeric
10D69	10D6D	Combining_Mark
10D6E		Break_After
10EAB	10EAC	Combining_Mark
10EAD		Break_After
10EFC	10EFF	Combining_Mark
10F46	10F50	Combining_Mark
10F82	10F85	Combining_Mark
11000	11002	Combining_Mark
11003	11004	Aksara_Prebase
11005	11037	Aksara
11038	11045	Combining_Mark
11046		Virama
11047	11048	Break_After
11049	1104D	Ideographic
11052	11065	Ideographic
11066	1106F	Aksara_Start
11070		Combining_Mark
11071	11072	Aksara
11073	11074	Combining_Mark
11075		Aksara
1107F		Glue
11080	11082	Combining_Mark
110B0	110BA	Combining_Mark
110BD		Numeric
110BE	110C1	Break_After
110C2		Combining_Mark
110CD		Numeric
110F0	110F9	Numeric
11100	11102	Combining_Mark
11127	11134	Combining_Mark
11136	1113F	Numeric
11140	11143	Break_After
11145	11146	Combining_Mark
11173		Combining_Mark
11175		Break_Before
11180	11182	Combining_Mark
111B3	111C0	Combining_Mark
111C5	111C6	Break_After
111C8		Break_After
111C9	111CC	Combining_Mark
111CE	111CF	Combining_Mark
111D0	111D9	Numeric
111DB		Break_Before
111DD	111DF	Break_After
1122C	11237	Combining_Mark
11238	11239	Break_After
1123B	1123C	Break_After
1123E		Combining_Mark
11241		Combining_Mark
112A9		Break_After
112DF	112EA	Combining_Mark
112F0	112F9	Numeric
11300	11303	Combining_Mark
11305	1130C	Aksara
1130F	11310	Aksara
11313	11328	Aksara
1132A	11330	Aksara
11332	11333	Aksara
11335	11339	Aksara
1133B	1133C	Combining_Mark
1133D		Break_After
1133E	11344	Combining_Mark
11347	11348	Combining_Mark
1134B	1134C	Combining_Mark
1134D		Virama
11350		Aksara_Start
11357		Combining_Mark
1135D		Break_After
1135E	1135F	Aksara_Start
11360	11361	Aksara
11362	11363	Combining_Mark
11366	1136C	Combining_Mark
11370	11374	Combining_Mark
11380	11389	Aksara_Start
1138B		Aksara_Start
1138E		Aksara_Start
11390	11391	Aksara_Start
11392	113B5	Aksara
113B7		Ideographic
113B8	113C0	Combining_Mark
113C2		Combining_Mark
113C5		Combining_Mark
113C7	113CA	Combining_Mark
113CC	113CF	Combining_Mark
113D0		Virama
113D1		Aksara_Prebase
113D2		Combining_Mark
113D3	113D5	Ideographic
113D7	113D8	Ideographic
113E1	113E2	Combining_Mark
11435	11446	Combining_Mark
1144B	1144E	Break_After
11450	11459	Numeric
1145A	1145B	Break_After
1145E		Combining_Mark
114B0	114C3	Combining_Mark
114D0	114D9	Numeric
115AF	115B5	Combining_Mark
115B8	115C0	Combining_Mark
115C1		Break_Before
115C2	115C3	Break_After
115C4	115C5	Exclamation
115C9	115D7	Break_After
115DC	115DD	Combining_Mark
11630	11640	Combining_Mark
11641	11642	Break_After
11650	11659	Numeric
11660	1166C	Break_Before
116AB	116B7	Combining_Mark
116C0	116C9	Numeric
116D0	116E3	Numeric
1171D	1172B	Combining_Mark
11730	11739	Numeric
1173C	1173E	Break_After
1182C	1183A	Combining_Mark
118E0	118E9	Numeric
11900	11906	Aksara
11909		Aksara
1190C	11913	Aksara
11915	11916	Aksara
11918	1192F	Aksara
11930	11935	Combining_Mark
11937	11938	Combining_Mark
1193B	1193D	Combining_Mark
1193E		Virama
1193F		Aksara_Prebase
11940		Combining_Mark
11941		Aksara_Prebase
11942	11943	Combining_Mark
11944	11946	Break_After
11950	11959	Aksara_Start
119D1	119D7	Combining_Mark
119DA	119E0	Combining_Mark
119E2		Break_Before
119E4		Combining_Mark
11A01	11A0A	Combining_Mark
11A33	11A39	Combining_Mark
11A3B	11A3E	Combining_Mark
11A3F		Break_Before
11A41	11A44	Break_After
11A45		Break_Before
11A47		Combining_Mark
11A51	11A5B	Combining_Mark
11A8A	11A99	Combining_Mark
11A9A	11A9C	Break_After
11A9E	11AA0	Break_Before
11AA1	11AA2	Break_After
11B00	11B09	Break_Before
11BF0	11BF9	Numeric
11C2F	11C36	Combining_Mark
11C38	11C3F	Combining_Mark
11C41	11C45	Break_After
11C50	11C59	Numeric
11C70		Break_Before
11C71		Exclamation
11C92	11CA7	Combining_Mark
11CA9	11CB6	Combining_Mark
11D31	11D36	Combining_Mark
11D3A		Combining_Mark
11D3C	11D3D	Combining_Mark
11D3F	11D45	Combining_Mark
11D47		Combining_Mark
11D50	11D59	Numeric
11D8A	11D8E	Combining_Mark
11D90	11D91	Combining_Mark
11D93	11D97	Combining_Mark
11DA0	11DA9	Numeric
11EE0	11EF1	Aksara_Start
11EF2		Break_After
11EF3	11EF6	Combining_Mark
11EF7	11EF8	Break_After
11F00	11F01	Combining_Mark
11F02		Aksara_Prebase
11F03		Combining_Mark
11F04	11F10	Aksara
11F12	11F33	Aksara
11F34	11F3A	Combining_Mark
11F3E	11F41	Combining_Mark
11F42		Virama
11F43	11F44	Break_After
11F45	11F4F	Ideographic
11F50	11F59	Aksara_Start
11F5A		Combining_Mark
11FDD	11FE0	Postfix_Numeric
11FFF		Break_After
12470	12474	Break_After
13258	1325A	Open_Punctuation
1325B	1325D	Close_Punctuation
13282		Close_Punctuation
13286		Open_Punctuation
13287		Close_Punctuation
13288		Open_Punctuation
13289		Close_Punctuation
13379		Open_Punctuation
1337A	1337B	Close_Punctuation
1342F		Open_Punctuation
13430	13436	Glue
13437		Open_Punctuation
13438		Close_Punctuation
13439	1343B	Glue
1343C		Open_Punctuation
1343D		Close_Punctuation
1343E		Open_Punctuation
1343F		Close_Punctuation
13440		Combining_Mark
13447	13455	Combining_Mark
145CE		Open_Punctuation
145CF		Close_Punctuation
16100	1611D	Aksara_Start
1611E	1612F	Combining_Mark
16130	16139	Aksara_Start
16A60	16A69	Numeric
16A6E	16A6F	Break_After
16AC0	16AC9	Numeric
16AF0	16AF4	Combining_Mark
16AF5		Break_After
16B30	16B36	Combining_Mark
16B37	16B39	Break_After
16B44		Break_After
16B50	16B59	Numeric
16D6E	16D6F	Break_After
16D70	16D79	Numeric
16E97	16E98	Break_After
16F4F		Combining_Mark
16F51	16F87	Combining_Mark
16F8F	16F92	Combining_Mark
16FE0	16FE3	EA_NS
16FE4		EA_GL
16FF0	16FF1	EA_CM
17000	187F7	EA_ID
18800	18AFF	EA_ID
18B00	18CD5	EA_AL
18CFF		EA_AL
18D00	18D08	EA_ID
1AFF0	1AFF3	EA_AL
1AFF5	1AFFB	EA_AL
1AFFD	1AFFE	EA_AL
1B000	1B122	EA_ID
1B132		EA_NS
1B150	1B152	EA_NS
1B155		EA_NS
1B164	1B167	EA_NS
1B170	1B2FB	EA_ID
1BC9D	1BC9E	Combining_Mark
1BC9F		Break_After
1BCA0	1BCA3	Combining_Mark
1CCF0	1CCF9	Numeric
1CF00	1CF2D	Combining_Mark
1CF30	1CF46	Combining_Mark
1D165	1D169	Combining_Mark
1D16D	1D182	Combining_Mark
1D185	1D18B	Combining_Mark
1D1AA	1D1AD	Combining_Mark
1D242	1D244	Combining_Mark
1D300	1D356	EA_AL
1D360	1D376	EA_AL
1D7CE	1D7FF	Numeric
1DA00	1DA36	Combining_Mark
1DA3B	1DA6C	Combining_Mark
1DA75		Combining_Mark
1DA84		Combining_Mark
1DA87	1DA8A	Break_After
1DA9B	1DA9F	Combining_Mark
1DAA1	1DAAF	Combining_Mark
1E000	1E006	Combining_Mark
1E008	1E018	Combining_Mark
1E01B	1E021	Combining_Mark
1E023	1E024	Combining_Mark
1E026	1E02A	Combining_Mark
1E08F		Combining_Mark
1E130	1E136	Combining_Mark
1E140	1E149	Numeric
1E2AE		Combining_Mark
1E2EC	1E2EF	Combining_Mark
1E2F0	1E2F9	Numeric
1E2FF		Prefix_Numeric
1E4EC	1E4EF	Combining_Mark
1E4F0	1E4F9	Numeric
1E5EE	1E5EF	Combining_Mark
1E5F1	1E5FA	Numeric
1E8D0	1E8D6	Combining_Mark
1E944	1E94A	Combining_Mark
1E950	1E959	Numeric
1E95E	1E95F	Open_Punctuation
1ECAC		Postfix_Numeric
1ECB0		Postfix_Numeric
1F000	1F003	ExtPict_ID
1F004		EA_ExtPict_ID
1F005	1F02B	ExtPict_ID
1F02C	1F02F	Cn_ExtPict_ExtPict_ID
1F030	1F093	ExtPict_ID
1F094	1F09F	Cn_ExtPict_ExtPict_ID
1F0A0	1F0AE	ExtPict_ID
1F0AF	1F0B0	Cn_ExtPict_ExtPict_ID
1F0B1	1F0BF	ExtPict_ID
1F0C0		Cn_ExtPict_ExtPict_ID
1F0C1	1F0CE	ExtPict_ID
1F0CF		EA_ExtPict_ID
1F0D0		Cn_ExtPict_ExtPict_ID
1F0D1	1F0F5	ExtPict_ID
1F0F6	1F0FF	Cn_ExtPict_ExtPict_ID
1F10D	1F10F	ExtPict_AL
1F12F		ExtPict_AL
1F16C	1F171	ExtPict_AL
1F17E	1F17F	ExtPict_AL
1F18E		EA_ExtPict_AL
1F191	1F19A	EA_ExtPict_AL
1F1AD		ExtPict_AL
1F1AE	1F1E5	Cn_ExtPict_ExtPict_ID
1F1E6	1F1FF	Regional_Indicator
1F200		EA_ID
1F201	1F202	EA_ExtPict_ID
1F203	1F20F	Cn_ExtPict_ExtPict_ID
1F210	1F219	EA_ID
1F21A		EA_ExtPict_ID
1F21B	1F22E	EA_ID
1F22F		EA_ExtPict_ID
1F230	1F231	EA_ID
1F232	1F23A	EA_ExtPict_ID
1F23B		EA_ID
1F23C	1F23F	Cn_ExtPict_ExtPict_ID
1F240	1F248	EA_ID
1F249	1F24F	Cn_ExtPict_ExtPict_ID
1F250	1F251	EA_ExtPict_ID
1F252	1F25F	Cn_ExtPict_ExtPict_ID
1F260	1F265	EA_ExtPict_ID
1F266	1F2FF	Cn_ExtPict_ExtPict_ID
1F300	1F320	EA_ExtPict_ID
1F321	1F32C	ExtPict_ID
1F32D	1F335	EA_ExtPict_ID
1F336		ExtPict_ID
1F337	1F37C	EA_ExtPict_ID
1F37D		ExtPict_ID
1F37E	1F384	EA_ExtPict_ID
1F385		EA_EB
1F386	1F393	EA_ExtPict_ID
1F394	1F39B	ExtPict_ID
1F39C	1F39D	ExtPict_AL
1F39E	1F39F	ExtPict_ID
1F3A0	1F3B4	EA_ExtPict_ID
1F3B5	1F3B6	EA_ExtPict_AL
1F3B7	1F3BB	EA_ExtPict_ID
1F3BC		EA_ExtPict_AL
1F3BD	1F3C1	EA_ExtPict_ID
1F3C2	1F3C4	EA_EB
1F3C5	1F3C6	EA_ExtPict_ID
1F3C7		EA_EB
1F3C8	1F3C9	EA_ExtPict_ID
1F3CA		EA_EB
1F3CB	1F3CC	E_Base
1F3CD	1F3CE	ExtPict_ID
1F3CF	1F3D3	EA_ExtPict_ID
1F3D4	1F3DF	ExtPict_ID
1F3E0	1F3F0	EA_ExtPict_ID
1F3F1	1F3F3	ExtPict_ID
1F3F4		EA_ExtPict_ID
1F3F5	1F3F7	ExtPict_ID
1F3F8	1F3FA	EA_ExtPict_ID
1F3FB	1F3FF	E_Modifier
1F400	1F43E	EA_ExtPict_ID
1F43F		ExtPict_ID
1F440		EA_ExtPict_ID
1F441		ExtPict_ID
1F442	1F443	EA_EB
1F444	1F445	EA_ExtPict_ID
1F446	1F450	EA_EB
1F451	1F465	EA_ExtPict_ID
1F466	1F478	EA_EB
1F479	1F47B	EA_ExtPict_ID
1F47C		EA_EB
1F47D	1F480	EA_ExtPict_ID
1F481	1F483	EA_EB
1F484		EA_ExtPict_ID
1F485	1F487	EA_EB
1F488	1F48E	EA_ExtPict_ID
1F48F		EA_EB
1F490		EA_ExtPict_ID
1F491		EA_EB
1F492	1F49F	EA_ExtPict_ID
1F4A0		EA_ExtPict_AL
1F4A1		EA_ExtPict_ID
1F4A2		EA_ExtPict_AL
1F4A3		EA_ExtPict_ID
1F4A4		EA_ExtPict_AL
1F4A5	1F4A9	EA_ExtPict_ID
1F4AA		EA_EB
1F4AB	1F4AE	EA_ExtPict_ID
1F4AF		EA_ExtPict_AL
1F4B0		EA_ExtPict_ID
1F4B1	1F4B2	EA_ExtPict_AL
1F4B3	1F4FC	EA_ExtPict_ID
1F4FD	1F4FE	ExtPict_ID
1F4FF		EA_ExtPict_ID
1F500	1F506	EA_ExtPict_AL
1F507	1F516	EA_ExtPict_ID
1F517	1F524	EA_ExtPict_AL
1F525	1F531	EA_ExtPict_ID
1F532	1F53D	EA_ExtPict_AL
1F546	1F549	ExtPict_AL
1F54A		ExtPict_ID
1F54B	1F54E	EA_ExtPict_ID
1F54F		ExtPict_ID
1F550	1F567	EA_ExtPict_ID
1F568	1F573	ExtPict_ID
1F574	1F575	E_Base
1F576	1F579	ExtPict_ID
1F57A		EA_EB
1F57B	1F58F	ExtPict_ID
1F590		E_Base
1F591	1F594	ExtPict_ID
1F595	1F596	EA_EB
1F597	1F5A3	ExtPict_ID
1F5A4		EA_ExtPict_ID
1F5A5	1F5D3	ExtPict_ID
1F5D4	1F5DB	ExtPict_AL
1F5DC	1F5F3	ExtPict_ID
1F5F4	1F5F9	ExtPict_AL
1F5FA		ExtPict_ID
1F5FB	1F644	EA_ExtPict_ID
1F645	1F647	EA_EB
1F648	1F64A	EA_ExtPict_ID
1F64B	1F64F	EA_EB
1F676	1F678	Quotation
1F679	1F67B	Nonstarter
1F680	1F6A2	EA_ExtPict_ID
1F6A3		EA_EB
1F6A4	1F6B3	EA_ExtPict_ID
1F6B4	1F6B6	EA_EB
1F6B7	1F6BF	EA_ExtPict_ID
1F6C0		EA_EB
1F6C1	1F6C5	EA_ExtPict_ID
1F6C6	1F6CB	ExtPict_ID
1F6CC		EA_EB
1F6CD	1F6CF	ExtPict_ID
1F6D0	1F6D2	EA_ExtPict_ID
1F6D3	1F6D4	ExtPict_ID
1F6D5	1F6D7	EA_ExtPict_ID
1F6D8	1F6DB	Cn_ExtPict_ExtPict_ID
1F6DC	1F6DF	EA_ExtPict_ID
1F6E0	1F6EA	ExtPict_ID
1F6EB	1F6EC	EA_ExtPict_ID
1F6ED	1F6EF	Cn_ExtPict_ExtPict_ID
1F6F0	1F6F3	ExtPict_ID
1F6F4	1F6FC	EA_ExtPict_ID
1F6FD	1F6FF	Cn_ExtPict_ExtPict_ID
1F774	1F776	ExtPict_ID
1F777	1F77A	Cn_ExtPict_ExtPict_ID
1F77B	1F77F	ExtPict_ID
1F7D5	1F7D9	ExtPict_ID
1F7DA	1F7DF	Cn_ExtPict_ExtPict_ID
1F7E0	1F7EB	EA_ExtPict_ID
1F7EC	1F7EF	Cn_ExtPict_ExtPict_ID
1F7F0		EA_ExtPict_ID
1F7F1	1F7FF	Cn_ExtPict_ExtPict_ID
1F80C	1F80F	Cn_ExtPict_ExtPict_AL
1F848	1F84F	Cn_ExtPict_ExtPict_AL
1F85A	1F85F	Cn_ExtPict_ExtPict_AL
1F888	1F88F	Cn_ExtPict_ExtPict_AL
1F8AE	1F8AF	Cn_ExtPict_ExtPict_AL
1F8B0	1F8BB	ExtPict_AL
1F8BC	1F8BF	Cn_ExtPict_ExtPict_AL
1F8C0	1F8C1	ExtPict_AL
1F8C2	1F8FF	Cn_ExtPict_ExtPict_AL
1F90C		EA_EB
1F90D	1F90E	EA_ExtPict_ID
1F90F		EA_EB
1F910	1F917	EA_ExtPict_ID
1F918	1F91F	EA_EB
1F920	1F925	EA_ExtPict_ID
1F926		EA_EB
1F927	1F92F	EA_ExtPict_ID
1F930	1F939	EA_EB
1F93A		EA_ExtPict_ID
1F93B		Ideographic
1F93C	1F93E	EA_EB
1F93F	1F945	EA_ExtPict_ID
1F946		Ideographic
1F947	1F976	EA_ExtPict_ID
1F977		EA_EB
1F978	1F9B4	EA_ExtPict_ID
1F9B5	1F9B6	EA_EB
1F9B7		EA_ExtPict_ID
1F9B8	1F9B9	EA_EB
1F9BA		EA_ExtPict_ID
1F9BB		EA_EB
1F9BC	1F9CC	EA_ExtPict_ID
1F9CD	1F9CF	EA_EB
1F9D0		EA_ExtPict_ID
1F9D1	1F9DD	EA_EB
1F9DE	1F9FF	EA_ExtPict_ID
1FA00	1FA53	ExtPict_AL
1FA54	1FA5F	Cn_ExtPict_ExtPict_ID
1FA60	1FA6D	ExtPict_ID
1FA6E	1FA6F	Cn_ExtPict_ExtPict_ID
1FA70	1FA7C	EA_ExtPict_ID
1FA7D	1FA7F	Cn_ExtPict_ExtPict_ID
1FA80	1FA89	EA_ExtPict_ID
1FA8A	1FA8E	Cn_ExtPict_ExtPict_ID
1FA8F	1FAC2	EA_ExtPict_ID
1FAC3	1FAC5	EA_EB
1FAC6		EA_ExtPict_ID
1FAC7	1FACD	Cn_ExtPict_ExtPict_ID
1FACE	1FADC	EA_ExtPict_ID
1FADD	1FADE	Cn_ExtPict_ExtPict_ID
1FADF	1FAE9	EA_ExtPict_ID
1FAEA	1FAEF	Cn_ExtPict_ExtPict_ID
1FAF0	1FAF8	EA_EB
1FAF9	1FAFF	Cn_ExtPict_ExtPict_ID
1FBF0	1FBF9	Numeric
1FC00	1FFFD	Cn_ExtPict_ExtPict_ID
20000	2FFFD	EA_ID
30000	3FFFD	EA_ID
E0001		Combining_Mark
E0020	E007F	Combining_Mark
E0100	E01EF	Combining_Mark
END
